<html>
<head>
<style>
.breadcrumbs {
  margin-top : 10px;
}
p,pre,br{
  margin-top:0px;
  margin-bottom:0px;
}
ul{
  margin-top:12px;margin-bottom:12px;
}
</style>
</head>
<body>
{% for entity in entities %}
<div>
  {% if entity.isBook %}
    {% include "booktemplate.html" %}
  {% else %}
    {% if entity.isPage %}
      {% include "pagetemplate.html" %}
    {% endif %}
  {% endif %}
</div>
{% endfor %}
</body>
</html>
