<!DOCTYPE kpartgui>
<kpartgui version="17" name="kjots" >
<MenuBar>
  <Menu name="file">
   <Action name="akonadi_note_create"/>
   <Action name="akonadi_collection_create"/>
   <Separator/>
   <Action name="file_save"/>
   <Action name="save_to"/>
   <Action name="import"/>
   <Separator/>
   <Action name="renamefile"/>
   <Action name="deletefile"/>
   <Separator/>
   <Action name="file_print"/>
   <Action name="file_print_preview"/>
   <Separator/>
  </Menu>

  <Menu noMerge="1" name="format">
      <text>F&amp;ormat</text>
      <Action name="format_text_bold"/>
      <Action name="format_text_italic"/>
      <Action name="format_text_underline"/>
      <Action name="format_text_strikeout"/>
      <Action name="format_text_foreground_color"/>
      <Action name="format_text_background_color"/>
      <Separator/>
      <Action name="format_heading_level"/>
      <Separator/>
      <Action name="format_align_left"/>
      <Action name="format_align_center"/>
      <Action name="format_align_right"/>
      <Action name="format_align_justify"/>
      <Separator/>
      <Action name="format_list_style"/>
      <Action name="format_list_indent_more"/>
      <Action name="format_list_indent_less"/>
      <Action name="format_list_checkbox"/>
      <Separator/>
      <Action name="format_painter"/>
  </Menu>

  <Menu name="view">
    <text>&amp;View</text>
    <Action name="view_mode_two_columns" />
    <Action name="view_mode_three_columns" />
  </Menu>

  <Menu name="go">
   <text>&amp;Go</text>
   <Action name="go_next"/>
   <Action name="go_previous"/>
   <Separator/>
   <Action name="go_prev_book"/>
   <Action name="go_next_book"/>
  </Menu>

  <Menu name="tools">
   <text>&amp;Tools</text>
   <Action name="add_image"/>
   <Action name="insert_table"/>
   <Action name="insert_horizontal_rule"/>
   <Action name="manage_note_link"/>
   <Action name="insert_date"/>
   <Action name="copy_into_title"/>
  </Menu>

  <Action name="bookmarks"/>

  <Menu name="settings">
    <Action name="kjots_configure"/>
  </Menu>

  <Menu name="help">
  </Menu>
</MenuBar>

<Menu name="akonadi_itemview_contextmenu">
  <Action name="akonadi_note_create"/>
  <Separator/>
  <Action name="renamefile"/>
  <Action name="akonadi_note_change_color"/>
  <Separator/>
  <Action name="akonadi_item_copy"/>
  <Action name="akonadi_item_delete"/>
  <Separator/>
  <Action name="save_to"/>
  <Separator/>
  <Action name="akonadi_note_pin_unpin"/>
  <Action name="akonadi_note_lock_unlock"/>
</Menu>

<Menu name="akonadi_collectionview_contextmenu">
  <Action name="akonadi_note_create"/>
  <Action name="akonadi_collection_create"/>
  <Separator/>
  <Action name="renamefile"/>
  <Action name="akonadi_notebook_change_color"/>
  <Separator/>
  <Action name="akonadi_collection_copy"/>
  <Action name="akonadi_collection_delete"/>
  <Separator/>
  <Action name="save_to"/>
  <Separator/>
  <Action name="akonadi_notebook_lock_unlock"/>
</Menu>

<ToolBar name="mainToolBar" fullWidth="true" noMerge="1" iconText="icononly">
  <text>Main Toolbar</text>
  <Action name="akonadi_note_create"/>
  <Action name="akonadi_collection_create"/>
  <Separator/>
  <Action name="file_save"/>
  <Action name="file_print"/>
  <Separator/>
  <Action name="edit_cut"/>
  <Action name="edit_copy"/>
  <Action name="edit_paste"/>
  <Separator/>
  <Action name="edit_find"/>
</ToolBar>

     
<ToolBar name="textToolBar" iconText="icononly">
    <text>Text Toolbar</text>
    <Action name="format_text_bold"/>
    <Action name="format_text_italic"/>
    <Action name="format_text_underline"/>
    <Action name="format_text_strikeout"/>
    <Action name="format_text_foreground_color"/>
    <Action name="format_text_background_color"/>
    <Separator/>
    <Action name="format_font_family"/>
    <Action name="format_font_size"/>
    <Separator/>
    <Action name="format_painter"/>
</ToolBar>

<ToolBar name="formatToolBar" iconText="icononly">
    <text>Format Toolbar</text>
    <Action name="format_heading_level"/>
    <Separator/>
    <Action name="format_align_left"/>
    <Action name="format_align_center"/>
    <Action name="format_align_right"/>
    <Action name="format_align_justify"/>
    <Separator/>
    <Action name="format_list_style"/>
    <Action name="format_list_indent_more"/>
    <Action name="format_list_indent_less"/>
    <Action name="format_list_checkbox"/>
</ToolBar>

<ToolBar name="toolsToolBar">
    <text>Tools Toolbar</text>
    <Action name="add_image"/>
    <Action name="insert_table"/>
    <Action name="insert_horizontal_rule"/>
    <Action name="manage_note_link"/>
</ToolBar>
</kpartgui>
